@@ -7,7 +7,7 @@ from nowcasting_forecast.batch import make_batches
 from nowcasting_forecast.database.connection import DatabaseConnection
 from nowcasting_forecast.database.fake import make_fake_forecasts, make_fake_national_forecast
 from nowcasting_forecast.database.save import save
-from nowcasting_forecast.models.nwp_solar_simple import nwp_irradence_simple_run_all_batches
+from nowcasting_forecast.models.nwp_solar_simple import nwp_irradiance_simple_run_all_batches
 from nowcasting_forecast.utils import floor_30_minutes_dt
 
 N_GSP = 338
@@ -46,7 +46,7 @@ def run(db_url: str, fake: bool = False):
             make_batches()
 
             # make forecasts
-            forecasts = nwp_irradence_simple_run_all_batches()
+            forecasts = nwp_irradiance_simple_run_all_batches()
 
         # save forecasts
         save(forecasts=forecasts, session=session)
